@@ -1,16 +1,15 @@
 from json.decoder import JSONDecodeError
 from logging import INFO, DEBUG, WARNING, ERROR, CRITICAL, NOTSET, root, getLogger, NullHandler, Formatter, \
     StreamHandler, FileHandler, Logger
-from logging.handlers import RotatingFileHandler, TimedRotatingFileHandler
 from copy import deepcopy
 from os import mkdir, getenv
 from tools import Singleton
 from os.path import join as join_path, exists as exists_path
 from typing import List
-# from .handlers import DBHandler
 import pymysql
 from jsonschema import validate as schema_validate, ValidationError
 from json import loads as json_loads
+from .handlers import RotatingFileHandler, TimedRotatingFileHandler
 
 root.setLevel(ERROR)
 root.addHandler(StreamHandler())
@@ -60,11 +59,11 @@ class LoggingConfig:
 
         if _rotationFileTypes[config['logging_rotation_type']] == _TIMED_ROTATION:
             when, interval = config['logging_interval'].split(' ')
-            handler = TimedRotatingFileHandler(config['file_name'], when=when, backupCount=config['backup_count'],
-                                               interval=int(interval))
+            handler = TimedRotatingFileHandler(config['file_name'], when=when, backup_count=config['backup_count'],
+                                               interval=int(interval), compression=config['compression'])
         elif _rotationFileTypes[config['logging_rotation_type']] == _SIZE_ROTATION:
-            handler = RotatingFileHandler(config['file_name'], maxBytes=int(config['logging_interval']),
-                                          backupCount=config['backup_count'])
+            handler = RotatingFileHandler(config['file_name'], max_bytes=int(config['logging_interval']),
+                                          backup_count=config['backup_count'], compression=config['compression'])
         else:
             handler = FileHandler(config['file_name'])
 
